#!/bin/bash

#
#WMS sensor install scrypt
#
#stefano.dalpra@cnaf.infn.it
#

GLITE_LOCATION=${GLITE_LOCATION:-/opt/glite}

#########################################################
#
#                               Integration changes
#. ${GLITE_LOCATION}/etc/glite-wms-vars.sh
#. ${GLITE_LOCATION}/libexec/glite-wms-services-certs.sh
#. ${GLITE_LOCATION}/etc/profile.d/glite-wms.sh
#. ${GLITE_LOCATION}/etc/profile.d/glite-wms-config.sh

. /etc/glite/profile.d/glite_setenv.sh

#STEP 0
#First i want be sure to be executing as root
MY_ID=`id|sed -ne 's/^uid=\([0-9]*\)(.*$/\1/p'`

if [ $MY_ID -ne "0" ] 
then
    echo "It seems you are not executing this script as root"
    echo "please execute me as root "
    exit
else
    echo "You are superuser. Good"
fi

if [ ! "$GLITE_WMS_TMP" ]
then
    echo "ERROR:"
    echo "GLITE_WMS_TMP environment variable is not set."
    echo "It should be already, in a tipical glite install."
    exit
fi

if [ ! "$GLITE_LOCATION" ]
then
    echo "ERROR:"
    echo "CONDORG_INSTALL_PATH environment variable is not set."
    echo "It should be already, in a tipical glite-rb install."
    exit
fi


#STEP1 
#
#I want be sure that the lbserver20 mysql database exists

LB_DBNAME="lbserver20"

LB_DBPWD=`grep -i -R -A 3 "<mysql.root.password" $GLITE_LOCATION/etc/config/glite-wms.cfg.xml |sed -ne "s/^.*value='\(.*\)'.*$/\1/p"`

GRANT_CMD="GRANT SELECT ON lbserver20.* TO 'lbserver20'@'localhost';"
FLUSH_CMD="FLUSH PRIVILEGES;"

LB_DBNAME_FOUND=`echo "SHOW DATABASES;" |mysql -u root -p$LB_DBPWD |grep $LB_DBNAME `
ESITO=$?

if [ $ESITO -ne "0" ]
then
    echo "ERROR:"
    echo "I cannot see the lbserver20 mysql database."
    echo "This could mean that you did set a password to "
    echo "access mysql as root or that you are using a different"
    echo "name than lbserver20 for the database, or a few many "
    echo "other reasons. Please proceed manually as follow:"
    echo
    echo "You must manually issue following commands"
    echo "from within superuser's mysql prompt:"
    echo $GRANT_CMD
    echo $FLUSH_CMD
    exit
fi

if [ "$LB_DBNAME_FOUND" != "$LB_DBNAME" ] 
then
    echo "ERROR:"
    echo "The lbserver20 database does not exists"
    echo "Be sure that the lbserver20 mysql database exists."
    echo "If not check your glite installation."
    exit
fi

#
#Now i create an 'lbserver20'@'localhost' user with select priv 
#for lbserver20 db 
#

echo "EXECUTING echo $GRANT_CMD|mysql ..."
echo $GRANT_CMD | mysql -u root -p$LB_DBPWD
if [ $? -ne "0" ]
then
    echo "ERROR: GRANT failed"
    echo "cannot grant select permission to lbserver20 database"
    echo "for the 'lbserver20'@'localhost' mysql user"
    echo "You must proceed manually. See INSTALL for instructions"
    exit
fi

echo "EXECUTING echo $FLUSH_CMD|mysql ..."
echo $FLUSH_CMD|mysql -u root -p$LB_DBPWD
if [ $? -ne "0" ]
then
    echo "ERROR: FLUSH failed"
    echo "This is weird, indeed."
    echo "Ask your system aministrator."
    exit
fi

#
#check for glite and condor environment variables
#


if [ ! "$GLITE_LOCATION_LOG" ]
then
    echo "ERROR:"
    echo "GLITE_LOCATION_LOG environment variable is not set."
    echo "It should be already, in a tipical glite install."
    exit
fi
if [ ! "$CONDORG_INSTALL_PATH" ]
then
    echo "ERROR:"
    echo "CONDORG_INSTALL_PATH environment variable is not set."
    echo "It should be already, in a tipical condor install."
    exit
fi
if [ ! "$CONDOR_CONFIG" ]
then
    echo "ERROR:"
    echo "CONDOR_CONFIG environment variable is not set."
    echo "It should be already, in a tipical condor install."
    exit
fi


#chmod u+x ./glite-wms-stats
#cp ./glite-wms-stats $GLITE_LOCATION/bin
#chmod u+x $GLITE_LOCATION/bin/glite-wms-stats

#echo " ./glite-wms-stats copied in /usr/local/bin"

# Set up the glite-wms-stats.cron file

echo "GLITE_LOCATION=$GLITE_LOCATION" > /etc/cron.d/glite-wms-stats.cron

echo "GLITE_LOCATION_LOG=$GLITE_LOCATION_LOG" >> /etc/cron.d/glite-wms-stats.cron
echo "GLITE_WMS_TMP=$GLITE_WMS_TMP" >> /etc/cron.d/glite-wms-stats.cron
echo "CONDORG_INSTALL_PATH=$CONDORG_INSTALL_PATH" >> /etc/cron.d/glite-wms-stats.cron
echo "CONDOR_CONFIG=$CONDOR_CONFIG" >> /etc/cron.d/glite-wms-stats.cron

BASE=$(($RANDOM%60))

echo "$BASE,$((($BASE+30)%60)) * * * * root $GLITE_LOCATION/bin/glite-wms-stats -plain >$GLITE_LOCATION_LOG/glite-wms-stats.last && cat $GLITE_LOCATION_LOG/glite-wms-stats.last >>$GLITE_LOCATION_LOG/glite-wms-stats.history ">>/etc/cron.d/glite-wms-stats.cron

chmod u+x /etc/cron.d/glite-wms-stats.cron

echo "Added /etc/cron.d/glite-wms-stats.cron"

echo "installation complete"





